@@ -75,7 +75,7 @@ from lino_xl.lib.working.ui import load_sessions, TOTAL_KEY
 
 
 class Event(Event, ContactRelated):
-    class Meta:
+    class Meta(Event.Meta):
         app_label = 'cal'
         abstract = dd.is_abstract_model(__name__, 'Event')
 
@@ -97,9 +97,10 @@ class RoomDetail(dd.DetailLayout):
 class EventDetail(EventDetail):
     start = "start_date start_time"
     end = "end_date end_time"
+    notify = "notify_before notify_unit"
     main = "general GuestsByEvent"
     general = dd.Panel("""
-    event_type:20 summary:60 id
+    event_type:20 summary:60 id notify
     start end access_class #all_day #assigned_to #duration #state
     user room company contact_person
     project owner workflow_buttons
