@@ -11,8 +11,8 @@ Defines a customized :class:`TicketDetail`.
 from lino.api import _
 from lino.mixins.sequenced import Hierarchical
 from lino.modlib.users.mixins import Assignable
-from lino.modlib.summaries.mixins import Summarized
 from lino_xl.lib.tickets.models import *
+from lino_xl.lib.working.mixins import SummarizedFromSession
 from lino_xl.lib.working.choicelists import ReportingTypes, ZERO_DURATION
 from lino.modlib.search.mixins import ElasticSearchable
 
@@ -52,7 +52,7 @@ class Site(Site):
     #    rt.models.tickets.Subscription.objects.create(user=ar.get_user(), site=self)
 
 
-class Ticket(Ticket, Assignable, Summarized, Hierarchical, ElasticSearchable):
+class Ticket(Ticket, Assignable, SummarizedFromSession, Hierarchical, ElasticSearchable):
 
     class Meta(Ticket.Meta):
         # app_label = 'tickets'
@@ -262,14 +262,6 @@ class Ticket(Ticket, Assignable, Summarized, Hierarchical, ElasticSearchable):
     def add_from_comment(self, obj):
         self.last_commenter = obj.user
 
-    def add_from_session(self, obj):
-        d = obj.get_duration()
-        if d:
-            rt = obj.get_reporting_type()
-            k = rt.name + '_hours'
-            value = getattr(self, k) + d
-            setattr(self, k, value)\
-
     @dd.chooser()
     def site_choices(cls, ar):
         # if user is None:
